Ingot.DTO.Assignment (Ingot v0.1.0)
View SourceLabeling task with context.
An assignment represents a single labeling task given to a user, including the sample to label, schema definition, and any existing labels for review/adjudication scenarios.
Summary
Types
@type t() :: %Ingot.DTO.Assignment{ assigned_at: DateTime.t(), existing_labels: [Ingot.DTO.Label.t()], id: String.t(), metadata: map(), queue_id: String.t(), sample: Ingot.DTO.Sample.t(), schema: map() }