IngotWeb.HealthController (Ingot v0.1.0)
View SourceHealth check endpoint for monitoring and alerting.
Returns JSON with overall status and individual service health checks.
Summary
Functions
GET /health
Health check endpoint for monitoring and alerting.
Returns JSON with overall status and individual service health checks.
GET /health